@@ -13,21 +13,21 @@ class ExtensionTest(unittest.TestCase):
 
     def test_initiate_expression(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/extension/initiate_expression.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/extension/initiate_expression.bpmn")[0]
 
         state = engine.invoke_by_id(ref, {"A": False})
         self.assertEqual(state.properties, {"A": True, "B": True})
 
     def test_continue_expression(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/extension/continue_expression.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/extension/continue_expression.bpmn")[0]
 
         state = engine.invoke_by_id(ref, {"A": False})
         self.assertEqual(state.properties, {"A": False, "B": True})
 
     def test_complete_expression(self):
         engine = SequentialBpmnEngine()
-        ref = engine.deploy(Path(__file__).parent / "diagrams/extension/complete_expression.bpmn")[0]
+        ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/extension/complete_expression.bpmn")[0]
 
         state = engine.invoke_by_id(ref, {"A": False})
         self.assertEqual(state.properties, {"A": False, "B": True, "C": True})
