@@ -4,6 +4,7 @@ from pathlib import Path
 
 from arrow_bpmn.engine.sequential_bpmn_engine import SequentialBpmnEngine
 from arrow_bpmn.parser.json.json_bpmn_parser import JsonBpmnParser
+from arrow_bpmn.parser.xml.arrow_xml_bpmn_parser import ArrowXmlBpmnParser
 
 
 class ProcessSerializationTest(unittest.TestCase):
@@ -13,7 +14,7 @@ class ProcessSerializationTest(unittest.TestCase):
         logging.basicConfig(level=logging.INFO)
 
     def compare(self, source: str):
-        engine = SequentialBpmnEngine()
+        engine = SequentialBpmnEngine(parser=ArrowXmlBpmnParser())
         ref = engine.deploy("customGroup", Path(__file__).parent / source)[0]
 
         parser = JsonBpmnParser()
@@ -69,4 +70,7 @@ class ProcessSerializationTest(unittest.TestCase):
         self.compare("diagrams/receive_task.bpmn")
 
     def test_service_task(self):
-        self.compare("diagrams/service_task.bpmn")
\ No newline at end of file
+        self.compare("diagrams/service_task.bpmn")
+
+    def test_http_task(self):
+        self.compare("diagrams/http_task.bpmn")
\ No newline at end of file
