@@ -1,9 +1,11 @@
 from dataclasses import dataclass
 from typing import Optional
 
+from arrow_bpmn.__spi__.registry.process_ref import ProcessRef
+
 
 @dataclass
-class NodeRef:
+class NodeRef(ProcessRef):
     """
     The NodeRef class is used to define the node invocation target of an event.
     This implementation can point to a start event, task or intermediate catching event.
@@ -12,7 +14,6 @@ class NodeRef:
     needs the process instance id and node instance id as well.
     """
 
-    process_id: str
     node_id: str
     process_instance_id: Optional[str] = None
     node_instance_id: Optional[str] = None
@@ -20,13 +21,13 @@ class NodeRef:
     @staticmethod
     def parse(text: str):
         array = text.split(":")
-        assert len(array) == 2 or len(array) == 4, "invalid node ref string representation"
+        assert len(array) == 3 or len(array) == 5, "invalid node ref string representation"
 
-        if len(array) == 2:
-            return NodeRef(array[0], array[1])
-        return NodeRef(array[0], array[1], array[2], array[3])
+        if len(array) == 3:
+            return NodeRef(array[0], array[1], array[2])
+        return NodeRef(array[0], array[1], array[2], array[3], array[4])
 
     def __repr__(self):
         if self.process_instance_id is not None and self.node_instance_id is not None:
-            return self.process_id + ":" + self.node_id + ":" + self.process_instance_id + ":" + self.node_instance_id
-        return self.process_id + ":" + self.node_id
+            return self.group + ":" + self.process_id + ":" + self.node_id + ":" + self.process_instance_id + ":" + self.node_instance_id
+        return self.group + ":" + self.process_id + ":" + self.node_id
