@@ -1,7 +1,7 @@
 import logging
 from collections import OrderedDict
 from dataclasses import dataclass
-from typing import Optional, Callable
+from typing import Optional
 
 from scriptable.abstract_engine import ScriptableEngine
 from scriptable.hypothesis_engine import HypothesisEngine
@@ -9,7 +9,7 @@ from scriptable.mustache_engine import MustacheEngine
 from scriptable.typescript_engine import TypescriptEngine
 
 from arrow_bpmn.__spi__ import State
-from arrow_bpmn.__spi__.factory.script_factory import ScriptFactory
+from arrow_bpmn.__spi__.factory.script_factory import ScriptFactory, Script
 
 
 @dataclass
@@ -35,7 +35,7 @@ class CacheableScriptFactory(ScriptFactory):
     def __init__(self, cache_size: int):
         self.cache = LRUCache(cache_size)
 
-    def __call__(self, state: State, language: str, script: str) -> Callable[[dict], dict]:
+    def __call__(self, state: State, language: str, script: str) -> Script:
         key = str(hash(language + ":" + script))
 
         cached_item = self.cache[key]
