@@ -75,7 +75,7 @@ class SignalEvent(Event):
     name: str
 
     def __repr__(self):
-        return f"{self.group}:{self.name}"
+        return f"SignalEvent({self.group}:{self.name})"
 
 
 @dataclass
