@@ -25,9 +25,8 @@ class ScriptTask(BpmnNode):
     # noinspection PyBroadException
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
         try:
-            engine = environment.script_factory(self.script_format, self.script)
-            result = engine.execute(state.properties)
-            state[self.var_name] = result
+            engine = environment.script_factory(state, self.script_format, self.script)
+            state[self.var_name] = engine(state.properties)
         except Exception:
             return state, [EventAction(self.id, ErrorEvent(environment.group, "script-error"))]
 
