@@ -1,6 +1,6 @@
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
-from typing import List, Tuple
+from typing import List
 
 from arrow_bpmn.__spi__.types import BpmnSource
 from arrow_bpmn.model.process import Process
@@ -12,7 +12,7 @@ class BpmnParser(ABC):
     extension: ParserExtension = field(default_factory=lambda: ArrowParserExtension())
 
     @abstractmethod
-    def parse(self, source: BpmnSource) -> Tuple[str, List[Process]]:
+    def parse(self, source: BpmnSource) -> List[Process]:
         pass
 
     def _concat_dicts(self, dict1: dict, dict2: dict):
